struct cpuinfo_mock_file filesystem[] = {
	{
		.path = "/proc/cpuinfo",
		.size = 749,
		.content =
			"Processor\t: AArch64 Processor rev 4 (aarch64)\n"
			"processor\t: 4\n"
			"model name\t: AArch64 Processor rev 4 (aarch64)\n"
			"BogoMIPS\t: 26.00\n"
			"Features\t: fp asimd evtstrm aes pmull sha1 sha2 crc32\n"
			"CPU implementer\t: 0x41\n"
			"CPU architecture: 8\n"
			"CPU variant\t: 0x0\n"
			"CPU part\t: 0xd03\n"
			"CPU revision\t: 4\n"
			"\n"
			"processor\t: 5\n"
			"model name\t: AArch64 Processor rev 4 (aarch64)\n"
			"BogoMIPS\t: 26.00\n"
			"Features\t: fp asimd evtstrm aes pmull sha1 sha2 crc32\n"
			"CPU implementer\t: 0x41\n"
			"CPU architecture: 8\n"
			"CPU variant\t: 0x0\n"
			"CPU part\t: 0xd03\n"
			"CPU revision\t: 4\n"
			"\n"
			"processor\t: 6\n"
			"model name\t: AArch64 Processor rev 4 (aarch64)\n"
			"BogoMIPS\t: 26.00\n"
			"Features\t: fp asimd evtstrm aes pmull sha1 sha2 crc32\n"
			"CPU implementer\t: 0x41\n"
			"CPU architecture: 8\n"
			"CPU variant\t: 0x0\n"
			"CPU part\t: 0xd03\n"
			"CPU revision\t: 4\n"
			"\n"
			"Hardware\t: MT6797T\n",
	},
	{
		.path = "/system/build.prop",
		.size = 9280,
		.content =
			"\n"
			"import /custom/cip-build.prop\n"
			"# begin build properties\n"
			"# autogenerated by buildinfo.sh\n"
			"ro.build.cta=noncta\n"
			"ro.meizu.build.spt=0\n"
			"ro.build.id=MRA58K\n"
			"ro.build.mask.id=6.0-1498662354_intlstable\n"
			"ro.build.inside.id=6.0-20170628230554\n"
			"ro.build.version.incremental=1498663073\n"
			"ro.build.version.sdk=23\n"
			"ro.build.version.preview_sdk=0\n"
			"ro.build.version.codename=REL\n"
			"ro.build.version.all_codenames=REL\n"
			"ro.build.version.release=6.0\n"
			"ro.build.version.security_patch=2017-04-05\n"
			"ro.build.version.base_os=\n"
			"ro.build.date=Wed Jun 28 23:25:45 CST 2017\n"
			"ro.build.date.utc=1498663545\n"
			"ro.build.type=user\n"
			"ro.build.user=flyme\n"
			"ro.build.host=mz-builder-l1\n"
			"ro.build.tags=release-keys\n"
			"ro.build.flavor=full_meizu6797_6c_m-user\n"
			"# ro.product.cpu.abi and ro.product.cpu.abi2 are obsolete,\n"
			"# use ro.product.cpu.abilist instead.\n"
			"ro.product.cpu.abi=arm64-v8a\n"
			"ro.product.cpu.abilist=arm64-v8a,armeabi-v7a,armeabi\n"
			"ro.product.cpu.abilist32=armeabi-v7a,armeabi\n"
			"ro.product.cpu.abilist64=arm64-v8a\n"
			"ro.product.locale=en-US\n"
			"ro.wifi.channels=\n"
			"ro.board.platform=mt6797\n"
			"# ro.build.product is obsolete; use ro.product.device\n"
			"# Do not try to parse description, fingerprint, or thumbprint\n"
			"ro.build.characteristics=default\n"
			"ro.product.brand=Meizu\n"
			"ro.product.manufacturer=Meizu\n"
			"ro.build.display.id=Flyme 6.1.0.0G\n"
			"ro.product.model=PRO 6\n"
			"ro.meizu.product.model=PRO6\n"
			"ro.product.name=meizu_PRO6\n"
			"ro.product.device=PRO6\n"
			"ro.product.board=PRO6\n"
			"# ro.build.product is obsolete; use ro.product.device\n"
			"ro.build.product=PRO6\n"
			"# Do not try to parse ro.build.description or .fingerprint\n"
			"ro.build.description=meizu_PRO6-user 6.0 MRA58K 1498663073 release-keys\n"
			"ro.build.fingerprint=Meizu/meizu_PRO6/PRO6:6.0/MRA58K/1498663073:user/release-keys\n"
			"ro.meizu.project.id=m8097-5\n"
			"ro.product.flyme.model=8097\n"
			"ro.flyme.published = true\n"
			"ro.meizu.has_datamigration_app=true\n"
			"# end build properties\n"
			"#\n"
			"# from device/meizu/meizu6797_6c_m/system.prop\n"
			"#\n"
			"#\n"
			"# system.prop for generic sdk\n"
			"#\n"
			"\n"
			"rild.libpath=mtk-ril.so\n"
			"rild.libargs=-d /dev/ttyC0\n"
			"\n"
			"\n"
			"# MTK, Infinity, 20090720 {\n"
			"wifi.interface=wlan0\n"
			"# MTK, Infinity, 20090720 }\n"
			"\n"
			"# MTK, mtk03034, 20101210 {\n"
			"ro.mediatek.wlan.wsc=1\n"
			"# MTK, mtk03034 20101210}\n"
			"# MTK, mtk03034, 20110318 {\n"
			"ro.mediatek.wlan.p2p=1\n"
			"# MTK, mtk03034 20110318}\n"
			"\n"
			"# MTK, mtk03034, 20101213 {\n"
			"mediatek.wlan.ctia=0\n"
			"# MTK, mtk03034 20101213}\n"
			"\n"
			"\n"
			"#\n"
			"wifi.tethering.interface=ap0\n"
			"#\n"
			"\n"
			"ro.opengles.version=196608\n"
			"#ro.kernel.qemu=1\n"
			"\n"
			"wifi.direct.interface=p2p0\n"
			"dalvik.vm.heapgrowthlimit=256m\n"
			"dalvik.vm.heapsize=512m\n"
			"\n"
			"# USB MTP WHQL\n"
			"ro.sys.usb.mtp.whql.enable=0\n"
			"\n"
			"# Power off opt in IPO\n"
			"sys.ipo.pwrdncap=2\n"
			"\n"
			"ro.sys.usb.storage.type=mtp,mass_storage\n"
			"\n"
			"# USB BICR function\n"
			"ro.sys.usb.bicr=yes\n"
			"\n"
			"# USB Charge only function\n"
			"ro.sys.usb.charging.only=yes\n"
			"\n"
			"# audio\n"
			"ro.camera.sound.forced=0\n"
			"ro.audio.silent=0\n"
			"\n"
			"ro.zygote.preload.enable=0\n"
			"\n"
			"# temporary enables NAV bar (soft keys)\n"
			"qemu.hw.mainkeys=1\n"
			"\n"
			"ro.kernel.zio=38,108,105,16\n"
			"#ro.kernel.qemu=1\n"
			"#ro.kernel.qemu.gles=0\n"
			"#ro.boot.selinux=disable\n"
			"\n"
			"# Disable dirty region for Mali\n"
			"#debug.hwui.render_dirty_regions=false\n"
			"\n"
			"ro.sf.lcd_density=480\n"
			"\n"
			"# performance\n"
			"ro.mtk_perf_simple_start_win=1\n"
			"ro.mtk_perf_fast_start_win=0\n"
			"ro.mtk_perf_response_time=1\n"
			"\n"
			"# Define PhoneApp ToneVolume\n"
			"persist.dialpad.volume=60\n"
			"persist.dialpad.ecc.volume=60\n"
			"persist.dtmf.volume=70\n"
			"persist.call.waiting.volume=85\n"
			"persist.ring.back.volume=85\n"
			"\n"
			"#\n"
			"# ADDITIONAL_BUILD_PROPERTIES\n"
			"#\n"
			"ro.hardware.hifi.support=true\n"
			"ro.com.android.dateformat=MM-dd-yyyy\n"
			"ro.config.ringtone=03_Flyme.ogg\n"
			"ro.config.notification_sound=02_Reminder.ogg\n"
			"ro.config.mms_sound=01_Triumph.ogg\n"
			"ro.config.email_sound=02_Reminder.ogg\n"
			"ro.config.calendar_sound=03_Doorbell.ogg\n"
			"ro.config.alarm_alert=19_Waltz.ogg\n"
			"log.tag.VibeTonz=ERROR\n"
			"ro.carrier=unknown\n"
			"ro.mediatek.chip_ver=S01\n"
			"ro.mediatek.version.release=alps-mp-m0.mp9-V1.13.2_meizu6797.6c.m\n"
			"ro.mediatek.platform=MT6797\n"
			"ro.telephony.sim.count=2\n"
			"persist.radio.default.sim=0\n"
			"persist.radio.multisim.config=dsds\n"
			"persist.gemini.sim_num=2\n"
			"ro.gemini.smart_sim_switch=false\n"
			"ril.specific.sm_cause=0\n"
			"bgw.current3gband=0\n"
			"ril.external.md=0\n"
			"ro.mtk_cam_lomo_support=1\n"
			"ro.sf.hwrotation=0\n"
			"ro.mediatek.gemini_support=true\n"
			"persist.radio.fd.counter=15\n"
			"persist.radio.fd.off.counter=5\n"
			"persist.radio.fd.r8.counter=15\n"
			"persist.radio.fd.off.r8.counter=5\n"
			"drm.service.enabled=true\n"
			"fmradio.driver.enable=0\n"
			"ril.first.md=1\n"
			"ril.flightmode.poweroffMD=0\n"
			"ril.telephony.mode=0\n"
			"dalvik.vm.mtk-stack-trace-file=/data/anr/mtk_traces.txt\n"
			"mediatek.wlan.chip=CONSYS_MT6797\n"
			"mediatek.wlan.module.postfix=_consys_mt6797\n"
			"ril.read.imsi=1\n"
			"ril.radiooff.poweroffMD=0\n"
			"ro.frp.pst=/dev/block/platform/mtk-msdc.0/11230000.msdc0/by-name/frp\n"
			"ro.mediatek.version.branch=alps-mp-m0.mp9\n"
			"ro.mediatek.version.sdk=4\n"
			"ro.mtk_gemini_support=1\n"
			"persist.radio.gemini_support=1\n"
			"ril.current.share_modem=2\n"
			"ro.mtk_audenh_support=1\n"
			"ro.mtk_bessurround_support=1\n"
			"ro.mtk_wapi_support=1\n"
			"ro.mtk_bt_support=1\n"
			"ro.mtk_wappush_support=1\n"
			"ro.mtk_agps_app=1\n"
			"ro.mtk_audio_tuning_tool_ver=V2.2\n"
			"ro.mtk_wlan_support=1\n"
			"ro.mtk_gps_support=1\n"
			"ro.mtk_omacp_support=1\n"
			"ro.mtk_search_db_support=1\n"
			"ro.mtk_dialer_search_support=1\n"
			"ro.mtk_dhcpv6c_wifi=1\n"
			"ro.have_aacencode_feature=1\n"
			"ro.mtk_fd_support=1\n"
			"ro.mtk_oma_drm_support=1\n"
			"ro.mtk_cta_drm_support=1\n"
			"ro.mtk_widevine_drm_l3_support=1\n"
			"ro.mtk_eap_sim_aka=1\n"
			"ro.mtk_audio_ape_support=1\n"
			"ro.mtk_flv_playback_support=1\n"
			"ro.mtk_wmv_playback_support=1\n"
			"ro.mtk_send_rr_support=1\n"
			"ro.mtk_emmc_support=1\n"
			"ro.mtk_tetheringipv6_support=1\n"
			"ro.telephony.default_network=9\n"
			"ro.mtk_shared_sdcard=1\n"
			"ro.mtk_enable_md1=1\n"
			"ro.mtk_afw_support=1\n"
			"ro.mtk_soter_support=1\n"
			"ro.mtk_benchmark_boost_tp=1\n"
			"ro.mtk_aal_support=1\n"
			"ro.mtk_pq_support=3\n"
			"ro.mtk_pq_color_mode=3\n"
			"ro.mtk_miravision_support=1\n"
			"ro.mtk_miravision_image_dc=1\n"
			"ro.mtk_blulight_def_support=1\n"
			"ro.mtk_wfd_support=1\n"
			"ro.mtk_wfd_sink_support=1\n"
			"ro.mtk_wfd_sink_uibc_support=1\n"
			"ro.mtk_wifi_mcc_support=1\n"
			"ro.mtk_sim_hot_swap=1\n"
			"ro.mtk_thumbnail_play_support=1\n"
			"ro.mtk_bip_scws=1\n"
			"ro.mtk_cmcc_ft_precheck_support=1\n"
			"ro.mtk_world_phone_policy=0\n"
			"ro.mtk_md_world_mode_support=1\n"
			"ro.mtk_perfservice_support=1\n"
			"ro.mtk_sim_hot_swap_common_slot=1\n"
			"ro.mtk_cta_set=1\n"
			"ro.mtk_mobile_management=1\n"
			"ro.mtk_antibricking_level=2\n"
			"ro.mtk_zsdhdr_support=1\n"
			"ro.mtk_cam_mfb_support=3\n"
			"ro.mtk_lte_support=1\n"
			"ro.mtk_safemedia_support=1\n"
			"ro.mtk_single_imei=1\n"
			"ro.mtk_cam_vfb=1\n"
			"ro.mtk_rild_read_imsi=1\n"
			"ro.sim_refresh_reset_by_modem=1\n"
			"ro.mtk_external_sim_support=1\n"
			"ro.mtk_persist_vsim_disabled=1\n"
			"ro.mtk_external_sim_only_slots=0\n"
			"ro.mtk_slidevideo_support=1\n"
			"ro.mtk_passpoint_r1_support=1\n"
			"ro.mtk_privacy_protection_lock=1\n"
			"ro.mtk_bg_power_saving_ui=1\n"
			"ro.have_aee_feature=1\n"
			"ro.sim_me_lock_mode=0\n"
			"ro.mtk_dual_mic_support=1\n"
			"ro.mtk_is_tablet=0\n"
			"ro.mtk_ims_support=1\n"
			"ro.mtk_vilte_support=0\n"
			"ro.mtk_vilte_ut_support=0\n"
			"wfd.dummy.enable=1\n"
			"wfd.iframesize.level=0\n"
			"ro.mediatek.project.path=device/meizu/meizu6797_6c_m\n"
			"ro.mtk_trustonic_tee_support=1\n"
			"ro.flyme_softsim_tee_enable=1\n"
			"persist.mtk.wcn.combo.chipid=-1\n"
			"persist.mtk.wcn.fwlog.status=no\n"
			"persist.mtk.wcn.dynamic.dump=0\n"
			"service.wcn.driver.ready=no\n"
			"service.wcn.coredump.mode=2\n"
			"ro.com.android.mobiledata=false\n"
			"persist.radio.mobile.data=0,0\n"
			"persist.radio.mobile.enable=1,1\n"
			"persist.meta.dumpdata=0\n"
			"ro.mtk_hetcomm_support=1\n"
			"ro.mtk_deinterlace_support=1\n"
			"ro.mtk_md_sbp_custom_value=0\n"
			"ro.mtk_modem_monitor_support=1\n"
			"persist.mtklog.modem.mini.log=1\n"
			"persist.power.usetwilightadj=true\n"
			"ro.meizu.enable.stepcounter=true\n"
			"persist.perf.url.wxhb=http://wx.gtimg.com/hongbao/1701/hb.png\n"
			"debug.hwui.render_dirty_regions=true\n"
			"ro.hwui.disable_asset_atlas=true\n"
			"dalvik.vm.heapgrowthlimit=256m\n"
			"dalvik.vm.heapsize=512m\n"
			"ro.hwui.texture_cache_size=48\n"
			"ro.hwui.layer_cache_size=32\n"
			"ro.hwui.r_buffer_cache_size=8\n"
			"ro.hwui.path_cache_size=32\n"
			"ro.hwui.gradient_cache_size=3\n"
			"ro.hwui.drop_shadow_cache_size=6\n"
			"ro.hwui.fbo_cache_size=25\n"
			"ro.hwui.texture_cache_flushrate=0.4\n"
			"ro.hwui.text_small_cache_width=1024\n"
			"ro.hwui.text_small_cache_height=1024\n"
			"ro.hwui.text_large_cache_width=2048\n"
			"ro.hwui.text_large_cache_height=1024\n"
			"ro.product.perf.config=M80_base\n"
			"persist.sf.startingwindow.gles=1\n"
			"persist.sys.app.compiler=speed\n"
			"persist.sys.app.thread=6\n"
			"persist.sys.plugin.thread=6\n"
			"persist.sys.plugin.compiler=interpret-only\n"
			"persist.sys.mstore.dl.num=1\n"
			"persist.sf.ssr.controlbar=0\n"
			"persist.sys.lock.charge=true\n"
			"ro.aeesp=normal\n"
			"ro.meizu.carrier.model=M570H\n"
			"persist.sys.timezone=Asia/Shanghai\n"
			"persist.sys.meizu.region=cn\n"
			"persist.sys.meizu.codepage=gbk\n"
			"ro.meizu.setupwizard.flyme=true\n"
			"ro.meizu.setupwizard.setlang=true\n"
			"ro.meizu.region.enable=true\n"
			"ro.meizu.contactmsg.auth=false\n"
			"ro.meizu.customize.pccw=false\n"
			"ro.meizu.autorecorder=true\n"
			"ro.meizu.visualvoicemail=true\n"
			"ro.meizu.security=false\n"
			"ro.meizu.permanentkey=false\n"
			"ro.meizu.sip.support=true\n"
			"ro.meizu.voip.support=false\n"
			"sys.meizu.m35x.white.config=false\n"
			"sys.meizu.white.config=false\n"
			"persist.sys.log-main.enable=0\n"
			"persist.sys.log-system.enable=0\n"
			"persist.sys.log-events.enable=0\n"
			"persist.sys.log-radio.enable=0\n"
			"persist.sys.use.flyme.icon=true\n"
			"ro.adb.secure=1\n"
			"persist.sys.ui.hw=true\n"
			"keyguard.no_require_sim=true\n"
			"persist.sys.keyguard_intercept=true\n"
			"persist.sys.disable_blur_view=true\n"
			"persist.sys.static_blur_mode=false\n"
			"ro.meizu.published.type=prd\n"
			"qemu.hw.mainkeys=1\n"
			"persist.sys.dalvik.vm.lib.2=libart\n"
			"dalvik.vm.isa.arm64.variant=cortex-a53\n"
			"dalvik.vm.isa.arm64.features=default\n"
			"dalvik.vm.isa.arm.variant=cortex-a53\n"
			"dalvik.vm.isa.arm.features=default\n"
			"net.bt.name=Android\n"
			"dalvik.vm.stack-trace-file=/data/anr/traces.txt\n"
			"ro.expect.recovery_id=0xc68184e76824cdec195acf3ae9c1a0b84b7f11d6000000000000000000000000\n",
	},
	{
		.path = "/sys/devices/system/cpu/kernel_max",
		.size = 2,
		.content = "9\n",
	},
	{
		.path = "/sys/devices/system/cpu/possible",
		.size = 4,
		.content = "0-9\n",
	},
	{
		.path = "/sys/devices/system/cpu/present",
		.size = 4,
		.content = "0-9\n",
	},
	{
		.path = "/sys/devices/system/cpu/online",
		.size = 4,
		.content = "4,8\n",
	},
	{
		.path = "/sys/devices/system/cpu/offline",
		.size = 8,
		.content = "0-3,6-9\n",
	},
	{
		.path = "/sys/devices/system/cpu/modalias",
		.size = 66,
		.content = "cpu:type:aarch64:feature:,0000,0001,0002,0003,0004,0005,0006,0007\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpufreq/all_time_in_state",
		.size = 890,
		.content =
			"freq\t\tcpu0\t\tcpu1\t\tcpu2\t\tcpu3\t\tcpu4\t\tcpu5\t\tcpu6\t\tcpu7\t\tcpu8\t\tcpu9\t\t\n"
			"221000\t\tN/A\t\tN/A\t\t\n"
			"325000\t\t15\t\tN/A\t\t\n"
			"338000\t\tN/A\t\t19\t\t\n"
			"468000\t\t0\t\tN/A\t\t\n"
			"481000\t\tN/A\t\tN/A\t\t\n"
			"624000\t\tN/A\t\tN/A\t\t\n"
			"650000\t\t0\t\tN/A\t\t\n"
			"676000\t\tN/A\t\t0\t\t\n"
			"715000\t\tN/A\t\tN/A\t\t\n"
			"806000\t\tN/A\t\tN/A\t\t\n"
			"832000\t\t7\t\tN/A\t\t\n"
			"845000\t\tN/A\t\t15\t\t\n"
			"897000\t\tN/A\t\tN/A\t\t\n"
			"962000\t\t35\t\tN/A\t\t\n"
			"1001000\t\tN/A\t\t11\t\t\n"
			"1014000\t\tN/A\t\tN/A\t\t\n"
			"1079000\t\t8\t\tN/A\t\t\n"
			"1118000\t\tN/A\t\tN/A\t\t\n"
			"1131000\t\tN/A\t\t0\t\t\n"
			"1209000\t\t122\t\tN/A\t\t\n"
			"1222000\t\tN/A\t\tN/A\t\t\n"
			"1274000\t\tN/A\t\tN/A\t\t\n"
			"1339000\t\tN/A\t\tN/A\t\t\n"
			"1352000\t\t189\t\tN/A\t\t\n"
			"1378000\t\tN/A\t\t0\t\t\n"
			"1391000\t\tN/A\t\tN/A\t\t\n"
			"1443000\t\tN/A\t\tN/A\t\t\n"
			"1495000\t\t4\t\t0\t\t\n"
			"1547000\t\tN/A\t\tN/A\t\t\n"
			"1625000\t\t14\t\tN/A\t\t\n"
			"1677000\t\tN/A\t\t0\t\t\n"
			"1703000\t\t6\t\tN/A\t\t\n"
			"1755000\t\t17\t\tN/A\t\t\n"
			"1820000\t\t10\t\tN/A\t\t\n"
			"1885000\t\t69\t\t4\t\t\n"
			"1950000\t\t38\t\tN/A\t\t\n"
			"2002000\t\t3223\t\tN/A\t\t\n"
			"2093000\t\tN/A\t\t4\t\t\n"
			"2158000\t\tN/A\t\t0\t\t\n"
			"2223000\t\tN/A\t\t0\t\t\n"
			"2262000\t\tN/A\t\t1\t\t\n"
			"2327000\t\tN/A\t\t952\t\t\n"
			"2392000\t\tN/A\t\t0\t\t\n"
			"2522000\t\tN/A\t\t191\t\t\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpufreq/current_in_state",
		.size = 1590,
		.content =
			"CPU0:1547000=0 1495000=0 1443000=0 1391000=0 1339000=0 1274000=0 1222000=0 1118000=0 1014000=0 897000=0 806000=0 715000=0 624000=0 481000=0 338000=0 221000=0 \n"
			"CPU1:1547000=0 1495000=0 1443000=0 1391000=0 1339000=0 1274000=0 1222000=0 1118000=0 1014000=0 897000=0 806000=0 715000=0 624000=0 481000=0 338000=0 221000=0 \n"
			"CPU2:1547000=0 1495000=0 1443000=0 1391000=0 1339000=0 1274000=0 1222000=0 1118000=0 1014000=0 897000=0 806000=0 715000=0 624000=0 481000=0 338000=0 221000=0 \n"
			"CPU3:1547000=0 1495000=0 1443000=0 1391000=0 1339000=0 1274000=0 1222000=0 1118000=0 1014000=0 897000=0 806000=0 715000=0 624000=0 481000=0 338000=0 221000=0 \n"
			"CPU4:1547000=0 1495000=0 1443000=0 1391000=0 1339000=0 1274000=0 1222000=0 1118000=0 1014000=0 897000=0 806000=0 715000=0 624000=0 481000=0 338000=0 221000=0 \n"
			"CPU5:1547000=0 1495000=0 1443000=0 1391000=0 1339000=0 1274000=0 1222000=0 1118000=0 1014000=0 897000=0 806000=0 715000=0 624000=0 481000=0 338000=0 221000=0 \n"
			"CPU6:1547000=0 1495000=0 1443000=0 1391000=0 1339000=0 1274000=0 1222000=0 1118000=0 1014000=0 897000=0 806000=0 715000=0 624000=0 481000=0 338000=0 221000=0 \n"
			"CPU7:1547000=0 1495000=0 1443000=0 1391000=0 1339000=0 1274000=0 1222000=0 1118000=0 1014000=0 897000=0 806000=0 715000=0 624000=0 481000=0 338000=0 221000=0 \n"
			"CPU8:1547000=0 1495000=0 1443000=0 1391000=0 1339000=0 1274000=0 1222000=0 1118000=0 1014000=0 897000=0 806000=0 715000=0 624000=0 481000=0 338000=0 221000=0 \n"
			"CPU9:1547000=0 1495000=0 1443000=0 1391000=0 1339000=0 1274000=0 1222000=0 1118000=0 1014000=0 897000=0 806000=0 715000=0 624000=0 481000=0 338000=0 221000=0 \n",
	},
	{
		.path = "/sys/devices/system/cpu/cpuidle/current_driver",
		.size = 18,
		.content = "mt67xx_v2_cpuidle\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpuidle/current_governor_ro",
		.size = 13,
		.content = "mtk_governor\n",
	},
	{
		.path = "/sys/devices/system/cpu/cputopo/cpus_per_cluster",
		.size = 39,
		.content =
			"cluster0: f\n"
			"cluster1: f0\n"
			"cluster2: 300\n",
	},
	{
		.path = "/sys/devices/system/cpu/cputopo/glbinfo",
		.size = 87,
		.content =
			"big/little arch: yes\n"
			"nr_cups: 10\n"
			"nr_clusters: 3\n"
			"cluster0: f\n"
			"cluster1: f0\n"
			"cluster2: 300\n",
	},
	{
		.path = "/sys/devices/system/cpu/cputopo/is_big_little",
		.size = 2,
		.content = "1\n",
	},
	{
		.path = "/sys/devices/system/cpu/cputopo/is_multi_cluster",
		.size = 2,
		.content = "1\n",
	},
	{
		.path = "/sys/devices/system/cpu/cputopo/nr_clusters",
		.size = 2,
		.content = "3\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/affected_cpus",
		.size = 2,
		.content = "4\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/cpuinfo_max_freq",
		.size = 8,
		.content = "2002000\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/cpuinfo_min_freq",
		.size = 7,
		.content = "325000\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/cpuinfo_transition_latency",
		.size = 5,
		.content = "1000\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/related_cpus",
		.size = 8,
		.content = "4 5 6 7\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/scaling_available_frequencies",
		.size = 124,
		.content = "2002000 1950000 1885000 1820000 1755000 1703000 1625000 1495000 1352000 1209000 1079000 962000 832000 650000 468000 325000 \n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/scaling_available_governors",
		.size = 13,
		.content = "interactive \n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/scaling_cur_freq",
		.size = 8,
		.content = "2002000\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/scaling_driver",
		.size = 11,
		.content = "mt-cpufreq\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/scaling_governor",
		.size = 12,
		.content = "interactive\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/scaling_min_freq",
		.size = 7,
		.content = "325000\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/stats/time_in_state",
		.size = 169,
		.content =
			"2002000 3298\n"
			"1950000 38\n"
			"1885000 69\n"
			"1820000 10\n"
			"1755000 17\n"
			"1703000 6\n"
			"1625000 14\n"
			"1495000 4\n"
			"1352000 189\n"
			"1209000 122\n"
			"1079000 8\n"
			"962000 35\n"
			"832000 7\n"
			"650000 0\n"
			"468000 0\n"
			"325000 15\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/stats/total_trans",
		.size = 3,
		.content = "94\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/stats/trans_table",
		.size = 2941,
		.content =
			"   From  :    To\n"
			"         :   2002000   1950000   1885000   1820000   1755000   1703000   1625000   1495000   1352000   1209000   1079000    962000    832000    650000    468000    325000 \n"
			"  2002000:         0         2         1         2         2         0         1         0         2         6         0         1         0         0         0         3 \n"
			"  1950000:         6         0         2         0         0         0         0         0         0         0         0         0         0         0         0         0 \n"
			"  1885000:         4         2         0         0         1         0         0         0         0         0         0         0         0         0         0         0 \n"
			"  1820000:         0         0         3         0         0         0         0         0         0         0         0         0         0         0         0         0 \n"
			"  1755000:         2         2         0         1         0         0         0         0         0         0         0         0         0         0         0         0 \n"
			"  1703000:         0         0         1         0         0         0         0         0         0         0         0         0         0         0         0         0 \n"
			"  1625000:         2         0         0         0         1         1         0         0         0         0         0         0         0         0         0         0 \n"
			"  1495000:         0         0         0         0         0         0         2         0         0         0         0         0         0         0         0         0 \n"
			"  1352000:         3         0         0         0         1         0         1         2         0         6         0         2         1         0         0         0 \n"
			"  1209000:         3         0         0         0         0         0         0         0        10         0         0         3         0         0         0         0 \n"
			"  1079000:         0         0         0         0         0         0         0         0         0         1         0         0         0         0         0         0 \n"
			"   962000:         0         0         0         0         0         0         0         0         3         3         1         0         0         0         0         0 \n"
			"   832000:         0         0         0         0         0         0         0         0         0         0         0         1         0         0         0         0 \n"
			"   650000:         0         0         0         0         0         0         0         0         0         0         0         0         0         0         0         0 \n"
			"   468000:         0         0         0         0         0         0         0         0         0         0         0         0         0         0         0         0 \n"
			"   325000:         1         2         0         0         0         0         0         0         0         0         0         0         0         0         0         0 \n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu4/cpufreq/affected_cpus",
		.size = 2,
		.content = "4\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu4/cpufreq/cpuinfo_max_freq",
		.size = 8,
		.content = "2002000\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu4/cpufreq/cpuinfo_min_freq",
		.size = 7,
		.content = "325000\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu4/cpufreq/cpuinfo_transition_latency",
		.size = 5,
		.content = "1000\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu4/cpufreq/related_cpus",
		.size = 8,
		.content = "4 5 6 7\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu4/cpufreq/scaling_available_frequencies",
		.size = 124,
		.content = "2002000 1950000 1885000 1820000 1755000 1703000 1625000 1495000 1352000 1209000 1079000 962000 832000 650000 468000 325000 \n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu4/cpufreq/scaling_available_governors",
		.size = 13,
		.content = "interactive \n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu4/cpufreq/scaling_cur_freq",
		.size = 8,
		.content = "2002000\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu4/cpufreq/scaling_driver",
		.size = 11,
		.content = "mt-cpufreq\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu4/cpufreq/scaling_governor",
		.size = 12,
		.content = "interactive\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu4/cpufreq/scaling_min_freq",
		.size = 7,
		.content = "325000\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu4/cpufreq/stats/time_in_state",
		.size = 170,
		.content =
			"2002000 4578\n"
			"1950000 38\n"
			"1885000 69\n"
			"1820000 10\n"
			"1755000 17\n"
			"1703000 14\n"
			"1625000 14\n"
			"1495000 9\n"
			"1352000 189\n"
			"1209000 122\n"
			"1079000 8\n"
			"962000 35\n"
			"832000 7\n"
			"650000 0\n"
			"468000 0\n"
			"325000 15\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu4/cpufreq/stats/total_trans",
		.size = 3,
		.content = "98\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu4/cpufreq/stats/trans_table",
		.size = 2941,
		.content =
			"   From  :    To\n"
			"         :   2002000   1950000   1885000   1820000   1755000   1703000   1625000   1495000   1352000   1209000   1079000    962000    832000    650000    468000    325000 \n"
			"  2002000:         0         2         1         2         2         1         1         1         2         6         0         1         0         0         0         3 \n"
			"  1950000:         6         0         2         0         0         0         0         0         0         0         0         0         0         0         0         0 \n"
			"  1885000:         4         2         0         0         1         0         0         0         0         0         0         0         0         0         0         0 \n"
			"  1820000:         0         0         3         0         0         0         0         0         0         0         0         0         0         0         0         0 \n"
			"  1755000:         2         2         0         1         0         0         0         0         0         0         0         0         0         0         0         0 \n"
			"  1703000:         1         0         1         0         0         0         0         0         0         0         0         0         0         0         0         0 \n"
			"  1625000:         2         0         0         0         1         1         0         0         0         0         0         0         0         0         0         0 \n"
			"  1495000:         1         0         0         0         0         0         2         0         0         0         0         0         0         0         0         0 \n"
			"  1352000:         3         0         0         0         1         0         1         2         0         6         0         2         1         0         0         0 \n"
			"  1209000:         3         0         0         0         0         0         0         0        10         0         0         3         0         0         0         0 \n"
			"  1079000:         0         0         0         0         0         0         0         0         0         1         0         0         0         0         0         0 \n"
			"   962000:         0         0         0         0         0         0         0         0         3         3         1         0         0         0         0         0 \n"
			"   832000:         0         0         0         0         0         0         0         0         0         0         0         1         0         0         0         0 \n"
			"   650000:         0         0         0         0         0         0         0         0         0         0         0         0         0         0         0         0 \n"
			"   468000:         0         0         0         0         0         0         0         0         0         0         0         0         0         0         0         0 \n"
			"   325000:         1         2         0         0         0         0         0         0         0         0         0         0         0         0         0         0 \n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu4/topology/physical_package_id",
		.size = 2,
		.content = "1\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu4/topology/core_siblings_list",
		.size = 4,
		.content = "4-7\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu4/topology/core_siblings",
		.size = 4,
		.content = "0f0\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu4/topology/core_id",
		.size = 2,
		.content = "0\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu4/topology/thread_siblings_list",
		.size = 2,
		.content = "4\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu4/topology/thread_siblings",
		.size = 4,
		.content = "010\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu5/cpufreq/affected_cpus",
		.size = 4,
		.content = "4 5\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu5/cpufreq/related_cpus",
		.size = 8,
		.content = "4 5 6 7\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu5/cpufreq/scaling_available_frequencies",
		.size = 124,
		.content = "2002000 1950000 1885000 1820000 1755000 1703000 1625000 1495000 1352000 1209000 1079000 962000 832000 650000 468000 325000 \n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu5/cpufreq/scaling_available_governors",
		.size = 13,
		.content = "interactive \n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu5/cpufreq/stats/time_in_state",
		.size = 170,
		.content =
			"2002000 5587\n"
			"1950000 38\n"
			"1885000 69\n"
			"1820000 10\n"
			"1755000 17\n"
			"1703000 14\n"
			"1625000 14\n"
			"1495000 9\n"
			"1352000 189\n"
			"1209000 122\n"
			"1079000 8\n"
			"962000 35\n"
			"832000 7\n"
			"650000 0\n"
			"468000 0\n"
			"325000 15\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu5/cpufreq/stats/total_trans",
		.size = 3,
		.content = "98\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu5/topology/thread_siblings",
		.size = 4,
		.content = "020\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu8/cpufreq/cpuinfo_min_freq",
		.size = 7,
		.content = "338000\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu8/cpufreq/cpuinfo_transition_latency",
		.size = 5,
		.content = "1000\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu8/cpufreq/scaling_cur_freq",
		.size = 8,
		.content = "2327000\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu8/cpufreq/scaling_driver",
		.size = 11,
		.content = "mt-cpufreq\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu8/cpufreq/scaling_min_freq",
		.size = 7,
		.content = "338000\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu8/cpufreq/stats/time_in_state",
		.size = 166,
		.content =
			"2522000 191\n"
			"2392000 0\n"
			"2327000 3012\n"
			"2262000 3\n"
			"2223000 0\n"
			"2158000 0\n"
			"2093000 10\n"
			"1885000 6\n"
			"1677000 2\n"
			"1495000 0\n"
			"1378000 0\n"
			"1131000 2\n"
			"1001000 11\n"
			"845000 22\n"
			"676000 0\n"
			"338000 19\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu8/cpufreq/stats/total_trans",
		.size = 4,
		.content = "525\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu8/topology/core_siblings_list",
		.size = 4,
		.content = "8-9\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu8/topology/core_siblings",
		.size = 4,
		.content = "300\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu8/topology/core_id",
		.size = 2,
		.content = "0\n",
	},
	{ NULL },
};

#ifdef __ANDROID__
struct cpuinfo_mock_property properties[] = {
	{
		.key = "af.rf_info",
		.value = "0",
	},
	{
		.key = "bgw.current3gband",
		.value = "0",
	},
	{
		.key = "camera.disable_zsl_mode",
		.value = "1",
	},
	{
		.key = "dalvik.vm.dex2oat-Xms",
		.value = "64m",
	},
	{
		.key = "dalvik.vm.dex2oat-Xmx",
		.value = "512m",
	},
	{
		.key = "dalvik.vm.heapgrowthlimit",
		.value = "256m",
	},
	{
		.key = "dalvik.vm.heapsize",
		.value = "512m",
	},
	{
		.key = "dalvik.vm.image-dex2oat-Xms",
		.value = "64m",
	},
	{
		.key = "dalvik.vm.image-dex2oat-Xmx",
		.value = "64m",
	},
	{
		.key = "dalvik.vm.isa.arm.features",
		.value = "default",
	},
	{
		.key = "dalvik.vm.isa.arm.variant",
		.value = "cortex-a53",
	},
	{
		.key = "dalvik.vm.isa.arm64.features",
		.value = "default",
	},
	{
		.key = "dalvik.vm.isa.arm64.variant",
		.value = "cortex-a53",
	},
	{
		.key = "dalvik.vm.mtk-stack-trace-file",
		.value = "/data/anr/mtk_traces.txt",
	},
	{
		.key = "dalvik.vm.stack-trace-file",
		.value = "/data/anr/traces.txt",
	},
	{
		.key = "debug.MB.running",
		.value = "0",
	},
	{
		.key = "debug.atrace.tags.enableflags",
		.value = "0",
	},
	{
		.key = "debug.force_rtl",
		.value = "0",
	},
	{
		.key = "debug.hwc.bq_count",
		.value = "4",
	},
	{
		.key = "debug.hwc.compose_level",
		.value = "0",
	},
	{
		.key = "debug.hwui.render_dirty_regions",
		.value = "true",
	},
	{
		.key = "debug.mdl.sdswap.path",
		.value = "/mnt/sdcard",
	},
	{
		.key = "debug.mdlogger.Running",
		.value = "0",
	},
	{
		.key = "debug.mdlogger.log2sd.path",
		.value = "internal_sd",
	},
	{
		.key = "debug.mtklog.netlog.Running",
		.value = "0",
	},
	{
		.key = "debug.program_binary.enable",
		.value = "1",
	},
	{
		.key = "debug.run.emdlogger1",
		.value = "1",
	},
	{
		.key = "dev.bootcomplete",
		.value = "1",
	},
	{
		.key = "drm.service.enabled",
		.value = "true",
	},
	{
		.key = "fmradio.driver.enable",
		.value = "0",
	},
	{
		.key = "gsm.baseband.capability",
		.value = "1023",
	},
	{
		.key = "gsm.current.phone-type",
		.value = "1,1",
	},
	{
		.key = "gsm.gcf.testmode",
		.value = "0",
	},
	{
		.key = "gsm.lte.ca.support",
		.value = "1",
	},
	{
		.key = "gsm.network.type",
		.value = "Unknown,Unknown",
	},
	{
		.key = "gsm.operator.alpha",
		.value = "",
	},
	{
		.key = "gsm.operator.alpha.2",
		.value = "",
	},
	{
		.key = "gsm.operator.iso-country",
		.value = "us",
	},
	{
		.key = "gsm.operator.isroaming",
		.value = "false,false",
	},
	{
		.key = "gsm.operator.numeric",
		.value = "310410",
	},
	{
		.key = "gsm.project.baseband",
		.value = "MEIZU6797_6C_M(LWCTG)",
	},
	{
		.key = "gsm.project.baseband.2",
		.value = "MEIZU6797_6C_M(LWCTG)",
	},
	{
		.key = "gsm.ril.ct3g",
		.value = "0",
	},
	{
		.key = "gsm.ril.ct3g.2",
		.value = "0",
	},
	{
		.key = "gsm.ril.eboot",
		.value = "-1",
	},
	{
		.key = "gsm.ril.init",
		.value = "1",
	},
	{
		.key = "gsm.ril.uicctype",
		.value = "USIM",
	},
	{
		.key = "gsm.ril.uicctype.2",
		.value = "USIM",
	},
	{
		.key = "gsm.serial",
		.value = "80MBCP5223WB                                                x7Fx7F",
	},
	{
		.key = "gsm.sim.operator.alpha",
		.value = ",",
	},
	{
		.key = "gsm.sim.operator.iso-country",
		.value = ",",
	},
	{
		.key = "gsm.sim.operator.numeric",
		.value = ",",
	},
	{
		.key = "gsm.sim.retry.pin1",
		.value = "",
	},
	{
		.key = "gsm.sim.retry.pin1.2",
		.value = "",
	},
	{
		.key = "gsm.sim.retry.pin2",
		.value = "",
	},
	{
		.key = "gsm.sim.retry.pin2.2",
		.value = "",
	},
	{
		.key = "gsm.sim.retry.puk1",
		.value = "",
	},
	{
		.key = "gsm.sim.retry.puk1.2",
		.value = "",
	},
	{
		.key = "gsm.sim.retry.puk2",
		.value = "",
	},
	{
		.key = "gsm.sim.retry.puk2.2",
		.value = "",
	},
	{
		.key = "gsm.sim.ril.mcc.mnc",
		.value = "",
	},
	{
		.key = "gsm.sim.ril.mcc.mnc.2",
		.value = "",
	},
	{
		.key = "gsm.sim.ril.phbready",
		.value = "false",
	},
	{
		.key = "gsm.sim.ril.phbready.2",
		.value = "true",
	},
	{
		.key = "gsm.sim.state",
		.value = "ABSENT,ABSENT",
	},
	{
		.key = "gsm.version.baseband",
		.value = "MOLY.LR11.W1539.MD.MP.V12.2.P133, 2017/03/27 11:37",
	},
	{
		.key = "gsm.version.baseband1",
		.value = "MOLY.LR11.W1539.MD.MP.V12.2.P133, 2017/03/27 11:37",
	},
	{
		.key = "gsm.version.ril-impl",
		.value = "mtk gemini ril 1.0",
	},
	{
		.key = "init.svc.DMAgent",
		.value = "running",
	},
	{
		.key = "init.svc.MPED",
		.value = "running",
	},
	{
		.key = "init.svc.MtkCodecService",
		.value = "running",
	},
	{
		.key = "init.svc.NvRAMAgent",
		.value = "running",
	},
	{
		.key = "init.svc.PPLAgent",
		.value = "running",
	},
	{
		.key = "init.svc.aal",
		.value = "running",
	},
	{
		.key = "init.svc.adbd",
		.value = "running",
	},
	{
		.key = "init.svc.agpsd",
		.value = "running",
	},
	{
		.key = "init.svc.batterywarning",
		.value = "running",
	},
	{
		.key = "init.svc.bootanim",
		.value = "stopped",
	},
	{
		.key = "init.svc.bootlogoupdater",
		.value = "stopped",
	},
	{
		.key = "init.svc.ccci3_fsd",
		.value = "stopped",
	},
	{
		.key = "init.svc.ccci3_mdinit",
		.value = "stopped",
	},
	{
		.key = "init.svc.ccci_fsd",
		.value = "running",
	},
	{
		.key = "init.svc.ccci_mdinit",
		.value = "running",
	},
	{
		.key = "init.svc.conn_launcher",
		.value = "running",
	},
	{
		.key = "init.svc.console",
		.value = "running",
	},
	{
		.key = "init.svc.debuggerd",
		.value = "running",
	},
	{
		.key = "init.svc.debuggerd64",
		.value = "running",
	},
	{
		.key = "init.svc.drm",
		.value = "running",
	},
	{
		.key = "init.svc.emdlogger1",
		.value = "running",
	},
	{
		.key = "init.svc.emsvr_user",
		.value = "running",
	},
	{
		.key = "init.svc.enableswap",
		.value = "stopped",
	},
	{
		.key = "init.svc.fingerprintd",
		.value = "running",
	},
	{
		.key = "init.svc.flash_recovery",
		.value = "stopped",
	},
	{
		.key = "init.svc.flymed",
		.value = "running",
	},
	{
		.key = "init.svc.fuelgauged",
		.value = "running",
	},
	{
		.key = "init.svc.gas_srv",
		.value = "running",
	},
	{
		.key = "init.svc.gatekeeperd",
		.value = "running",
	},
	{
		.key = "init.svc.ged_srv",
		.value = "running",
	},
	{
		.key = "init.svc.goodixfpd",
		.value = "running",
	},
	{
		.key = "init.svc.gsm0710muxd",
		.value = "running",
	},
	{
		.key = "init.svc.guiext-server",
		.value = "running",
	},
	{
		.key = "init.svc.healthd",
		.value = "running",
	},
	{
		.key = "init.svc.immvibed",
		.value = "running",
	},
	{
		.key = "init.svc.installd",
		.value = "running",
	},
	{
		.key = "init.svc.keystore",
		.value = "running",
	},
	{
		.key = "init.svc.lmkd",
		.value = "running",
	},
	{
		.key = "init.svc.logd",
		.value = "running",
	},
	{
		.key = "init.svc.logd-reinit",
		.value = "stopped",
	},
	{
		.key = "init.svc.mal-daemon",
		.value = "running",
	},
	{
		.key = "init.svc.md_monitor",
		.value = "running",
	},
	{
		.key = "init.svc.media",
		.value = "running",
	},
	{
		.key = "init.svc.mnld",
		.value = "running",
	},
	{
		.key = "init.svc.mobicore",
		.value = "running",
	},
	{
		.key = "init.svc.mobile_log_d",
		.value = "running",
	},
	{
		.key = "init.svc.msensord",
		.value = "stopped",
	},
	{
		.key = "init.svc.netd",
		.value = "running",
	},
	{
		.key = "init.svc.netdiag",
		.value = "running",
	},
	{
		.key = "init.svc.nvram_daemon",
		.value = "stopped",
	},
	{
		.key = "init.svc.p2p_supplicant",
		.value = "running",
	},
	{
		.key = "init.svc.pq",
		.value = "running",
	},
	{
		.key = "init.svc.program_binary",
		.value = "running",
	},
	{
		.key = "init.svc.ril-daemon",
		.value = "stopped",
	},
	{
		.key = "init.svc.ril-daemon-mtk",
		.value = "running",
	},
	{
		.key = "init.svc.servicemanager",
		.value = "running",
	},
	{
		.key = "init.svc.slpd",
		.value = "running",
	},
	{
		.key = "init.svc.spm_script",
		.value = "stopped",
	},
	{
		.key = "init.svc.stp_dump",
		.value = "running",
	},
	{
		.key = "init.svc.surfaceflinger",
		.value = "running",
	},
	{
		.key = "init.svc.synad",
		.value = "stopped",
	},
	{
		.key = "init.svc.terservice",
		.value = "stopped",
	},
	{
		.key = "init.svc.thermal",
		.value = "running",
	},
	{
		.key = "init.svc.thermal_manager",
		.value = "stopped",
	},
	{
		.key = "init.svc.thermald",
		.value = "running",
	},
	{
		.key = "init.svc.thermalloadalgod",
		.value = "running",
	},
	{
		.key = "init.svc.ueventd",
		.value = "running",
	},
	{
		.key = "init.svc.vold",
		.value = "running",
	},
	{
		.key = "init.svc.volte_imcb",
		.value = "stopped",
	},
	{
		.key = "init.svc.volte_stack",
		.value = "stopped",
	},
	{
		.key = "init.svc.volte_ua",
		.value = "stopped",
	},
	{
		.key = "init.svc.vtservice",
		.value = "running",
	},
	{
		.key = "init.svc.wifi2agps",
		.value = "running",
	},
	{
		.key = "init.svc.wmtLoader",
		.value = "stopped",
	},
	{
		.key = "init.svc.xlogboot",
		.value = "stopped",
	},
	{
		.key = "init.svc.xlogdebugchanged",
		.value = "stopped",
	},
	{
		.key = "init.svc.zygote",
		.value = "running",
	},
	{
		.key = "init.svc.zygote_secondary",
		.value = "running",
	},
	{
		.key = "keyguard.no_require_sim",
		.value = "true",
	},
	{
		.key = "log.tag.VibeTonz",
		.value = "ERROR",
	},
	{
		.key = "media.wfd.portrait",
		.value = "0",
	},
	{
		.key = "media.wfd.video-format",
		.value = "5",
	},
	{
		.key = "mediatek.wlan.chip",
		.value = "CONSYS_MT6797",
	},
	{
		.key = "mediatek.wlan.ctia",
		.value = "0",
	},
	{
		.key = "mediatek.wlan.module.postfix",
		.value = "_consys_mt6797",
	},
	{
		.key = "mtk.cpu.boost.disable",
		.value = "1",
	},
	{
		.key = "mtk.md1.starttime",
		.value = "1s Sat Aug 19 16:01:57 2017\n",
	},
	{
		.key = "mtk.md1.status",
		.value = "ready",
	},
	{
		.key = "mtk_wifi.fwpath",
		.value = "STA",
	},
	{
		.key = "net.bt.name",
		.value = "Android",
	},
	{
		.key = "net.change",
		.value = "net.qtaguid_enabled",
	},
	{
		.key = "net.hostname",
		.value = "android-71fc894a0efed538",
	},
	{
		.key = "net.nsiot_pending",
		.value = "false",
	},
	{
		.key = "net.perf.cpu.core",
		.value = "4,4,0,0,0,0",
	},
	{
		.key = "net.perf.cpu.freq",
		.value = "1118000,1391000,0,0,0,0",
	},
	{
		.key = "net.perf.rps",
		.value = "3ff",
	},
	{
		.key = "net.qtaguid_enabled",
		.value = "1",
	},
	{
		.key = "net.tcp.default_init_rwnd",
		.value = "60",
	},
	{
		.key = "persist.call.waiting.volume",
		.value = "85",
	},
	{
		.key = "persist.dbg.volte_avail_ovr",
		.value = "0",
	},
	{
		.key = "persist.dbg.vt_avail_ovr",
		.value = "0",
	},
	{
		.key = "persist.dbg.wfc_avail_ovr",
		.value = "0",
	},
	{
		.key = "persist.dialpad.ecc.volume",
		.value = "60",
	},
	{
		.key = "persist.dialpad.volume",
		.value = "60",
	},
	{
		.key = "persist.dm.lock",
		.value = "false",
	},
	{
		.key = "persist.dtmf.volume",
		.value = "70",
	},
	{
		.key = "persist.gemini.sim_num",
		.value = "2",
	},
	{
		.key = "persist.log.tag",
		.value = "V",
	},
	{
		.key = "persist.meta.dumpdata",
		.value = "0",
	},
	{
		.key = "persist.mtk.ims.video.enable",
		.value = "0",
	},
	{
		.key = "persist.mtk.volte.enable",
		.value = "0",
	},
	{
		.key = "persist.mtk.wcn.combo.chipid",
		.value = "0x6797",
	},
	{
		.key = "persist.mtk.wcn.dynamic.dump",
		.value = "0",
	},
	{
		.key = "persist.mtk.wcn.fwlog.status",
		.value = "no",
	},
	{
		.key = "persist.mtk.wfc.enable",
		.value = "0",
	},
	{
		.key = "persist.mtklog.modem.mini.log",
		.value = "1",
	},
	{
		.key = "persist.perf.url.wxhb",
		.value = "http://wx.gtimg.com/hongbao/1701/hb.png",
	},
	{
		.key = "persist.power.usetwilightadj",
		.value = "true",
	},
	{
		.key = "persist.radio.data.iccid",
		.value = "",
	},
	{
		.key = "persist.radio.default.sim",
		.value = "0",
	},
	{
		.key = "persist.radio.external-sim",
		.value = "",
	},
	{
		.key = "persist.radio.fd.counter",
		.value = "15",
	},
	{
		.key = "persist.radio.fd.off.counter",
		.value = "5",
	},
	{
		.key = "persist.radio.fd.off.r8.counter",
		.value = "5",
	},
	{
		.key = "persist.radio.fd.r8.counter",
		.value = "15",
	},
	{
		.key = "persist.radio.gemini_support",
		.value = "1",
	},
	{
		.key = "persist.radio.ia",
		.value = "",
	},
	{
		.key = "persist.radio.ia-apn",
		.value = "",
	},
	{
		.key = "persist.radio.mobile.data",
		.value = "0,0",
	},
	{
		.key = "persist.radio.mobile.enable",
		.value = "1,1",
	},
	{
		.key = "persist.radio.multisim.config",
		.value = "dsds",
	},
	{
		.key = "persist.radio.reset_on_switch",
		.value = "false",
	},
	{
		.key = "persist.radio.simswitch",
		.value = "1",
	},
	{
		.key = "persist.ring.back.volume",
		.value = "85",
	},
	{
		.key = "persist.service.acm.enable",
		.value = "0",
	},
	{
		.key = "persist.service.bdroid.bdaddr",
		.value = "22:22:96:1f:10:6c",
	},
	{
		.key = "persist.service.stk.shutdown",
		.value = "0",
	},
	{
		.key = "persist.sf.ssr.controlbar",
		.value = "0",
	},
	{
		.key = "persist.sf.startingwindow.gles",
		.value = "1",
	},
	{
		.key = "persist.sys.app.compiler",
		.value = "speed",
	},
	{
		.key = "persist.sys.app.thread",
		.value = "6",
	},
	{
		.key = "persist.sys.bluelight.enabled",
		.value = "0",
	},
	{
		.key = "persist.sys.dalvik.vm.lib.2",
		.value = "libart.so",
	},
	{
		.key = "persist.sys.disable_blur_view",
		.value = "true",
	},
	{
		.key = "persist.sys.fast_charge",
		.value = "1",
	},
	{
		.key = "persist.sys.fingerprint.hbd",
		.value = "false",
	},
	{
		.key = "persist.sys.first_time_boot",
		.value = "false",
	},
	{
		.key = "persist.sys.keyguard_intercept",
		.value = "true",
	},
	{
		.key = "persist.sys.lock.charge",
		.value = "true",
	},
	{
		.key = "persist.sys.log-events.enable",
		.value = "0",
	},
	{
		.key = "persist.sys.log-main.enable",
		.value = "0",
	},
	{
		.key = "persist.sys.log-radio.enable",
		.value = "0",
	},
	{
		.key = "persist.sys.log-system.enable",
		.value = "0",
	},
	{
		.key = "persist.sys.meizu.codepage",
		.value = "gbk",
	},
	{
		.key = "persist.sys.meizu.region",
		.value = "cn",
	},
	{
		.key = "persist.sys.mstore.dl.num",
		.value = "1",
	},
	{
		.key = "persist.sys.mute.state",
		.value = "2",
	},
	{
		.key = "persist.sys.plugin.compiler",
		.value = "interpret-only",
	},
	{
		.key = "persist.sys.plugin.thread",
		.value = "6",
	},
	{
		.key = "persist.sys.pq.adl.idx",
		.value = "0",
	},
	{
		.key = "persist.sys.pq.shp.idx",
		.value = "2",
	},
	{
		.key = "persist.sys.profiler_ms",
		.value = "0",
	},
	{
		.key = "persist.sys.sd.defaultpath",
		.value = "/storage/emulated/0",
	},
	{
		.key = "persist.sys.static_blur_mode",
		.value = "false",
	},
	{
		.key = "persist.sys.timezone",
		.value = "America/New_York",
	},
	{
		.key = "persist.sys.ui.hw",
		.value = "true",
	},
	{
		.key = "persist.sys.usb.config",
		.value = "mtp,adb",
	},
	{
		.key = "persist.sys.use.flyme.icon",
		.value = "true",
	},
	{
		.key = "qemu.hw.mainkeys",
		.value = "1",
	},
	{
		.key = "recovery.service.control",
		.value = "start",
	},
	{
		.key = "recovery.service.parameter",
		.value = "setMode=0",
	},
	{
		.key = "ril.active.md",
		.value = "9",
	},
	{
		.key = "ril.apc.support",
		.value = "1",
	},
	{
		.key = "ril.cdma.emdstatus.protocol",
		.value = "",
	},
	{
		.key = "ril.cdma.switching",
		.value = "0",
	},
	{
		.key = "ril.current.share_modem",
		.value = "2",
	},
	{
		.key = "ril.data.allow",
		.value = "0",
	},
	{
		.key = "ril.ecclist",
		.value = "",
	},
	{
		.key = "ril.ecclist1",
		.value = "",
	},
	{
		.key = "ril.external.md",
		.value = "0",
	},
	{
		.key = "ril.fd.mode",
		.value = "1",
	},
	{
		.key = "ril.first.md",
		.value = "1",
	},
	{
		.key = "ril.flightmode.poweroffMD",
		.value = "0",
	},
	{
		.key = "ril.gsm.imei",
		.value = "869015020390702,869015020390710",
	},
	{
		.key = "ril.ia.iccid",
		.value = "",
	},
	{
		.key = "ril.iccid.sim1",
		.value = "N/A",
	},
	{
		.key = "ril.iccid.sim2",
		.value = "N/A",
	},
	{
		.key = "ril.imsi.status.sim1",
		.value = "0",
	},
	{
		.key = "ril.imsi.status.sim2",
		.value = "0",
	},
	{
		.key = "ril.ipo.radiooff",
		.value = "0",
	},
	{
		.key = "ril.ipo.radiooff.2",
		.value = "0",
	},
	{
		.key = "ril.mal.flag",
		.value = "0",
	},
	{
		.key = "ril.mux.ee.md1",
		.value = "0",
	},
	{
		.key = "ril.mux.report.case",
		.value = "0",
	},
	{
		.key = "ril.nw.worldmode.activemode",
		.value = "1",
	},
	{
		.key = "ril.pid.1",
		.value = "1036",
	},
	{
		.key = "ril.radio.ia",
		.value = "",
	},
	{
		.key = "ril.radio.ia-apn",
		.value = "",
	},
	{
		.key = "ril.radiooff.poweroffMD",
		.value = "0",
	},
	{
		.key = "ril.read.imsi",
		.value = "1",
	},
	{
		.key = "ril.specific.sm_cause",
		.value = "0",
	},
	{
		.key = "ril.telephony.mode",
		.value = "0",
	},
	{
		.key = "ril.volte.hoe.interface0",
		.value = "0",
	},
	{
		.key = "ril.volte.hoe.interface1",
		.value = "0",
	},
	{
		.key = "ril.volte.hoe.interface10",
		.value = "0",
	},
	{
		.key = "ril.volte.hoe.interface11",
		.value = "0",
	},
	{
		.key = "ril.volte.hoe.interface12",
		.value = "0",
	},
	{
		.key = "ril.volte.hoe.interface13",
		.value = "0",
	},
	{
		.key = "ril.volte.hoe.interface14",
		.value = "0",
	},
	{
		.key = "ril.volte.hoe.interface15",
		.value = "0",
	},
	{
		.key = "ril.volte.hoe.interface2",
		.value = "0",
	},
	{
		.key = "ril.volte.hoe.interface3",
		.value = "0",
	},
	{
		.key = "ril.volte.hoe.interface4",
		.value = "0",
	},
	{
		.key = "ril.volte.hoe.interface5",
		.value = "0",
	},
	{
		.key = "ril.volte.hoe.interface6",
		.value = "0",
	},
	{
		.key = "ril.volte.hoe.interface7",
		.value = "0",
	},
	{
		.key = "ril.volte.hoe.interface8",
		.value = "0",
	},
	{
		.key = "ril.volte.hoe.interface9",
		.value = "0",
	},
	{
		.key = "ril.volte.hos.interface0",
		.value = "0",
	},
	{
		.key = "ril.volte.hos.interface1",
		.value = "0",
	},
	{
		.key = "ril.volte.hos.interface10",
		.value = "0",
	},
	{
		.key = "ril.volte.hos.interface11",
		.value = "0",
	},
	{
		.key = "ril.volte.hos.interface12",
		.value = "0",
	},
	{
		.key = "ril.volte.hos.interface13",
		.value = "0",
	},
	{
		.key = "ril.volte.hos.interface14",
		.value = "0",
	},
	{
		.key = "ril.volte.hos.interface15",
		.value = "0",
	},
	{
		.key = "ril.volte.hos.interface2",
		.value = "0",
	},
	{
		.key = "ril.volte.hos.interface3",
		.value = "0",
	},
	{
		.key = "ril.volte.hos.interface4",
		.value = "0",
	},
	{
		.key = "ril.volte.hos.interface5",
		.value = "0",
	},
	{
		.key = "ril.volte.hos.interface6",
		.value = "0",
	},
	{
		.key = "ril.volte.hos.interface7",
		.value = "0",
	},
	{
		.key = "ril.volte.hos.interface8",
		.value = "0",
	},
	{
		.key = "ril.volte.hos.interface9",
		.value = "0",
	},
	{
		.key = "ril.volte.mal.latency",
		.value = "65535",
	},
	{
		.key = "ril.volte.mal.opkey",
		.value = "0x0001",
	},
	{
		.key = "ril.volte.mal.pkterrth",
		.value = "99",
	},
	{
		.key = "ril.volte.mal.pktlosth",
		.value = "99",
	},
	{
		.key = "ril.volte.mal.rb_hoddc_t",
		.value = "3",
	},
	{
		.key = "ril.volte.mal.rb_hol2w_t",
		.value = "10",
	},
	{
		.key = "ril.volte.mal.rb_how2l_t",
		.value = "5",
	},
	{
		.key = "ril.volte.mal.retranth",
		.value = "99",
	},
	{
		.key = "ril.volte.mal.throupt",
		.value = "65535",
	},
	{
		.key = "rild.libargs",
		.value = "-d /dev/ttyC0",
	},
	{
		.key = "rild.libpath",
		.value = "mtk-ril.so",
	},
	{
		.key = "rild.mark_switchuser",
		.value = "0",
	},
	{
		.key = "ro.adb.secure",
		.value = "1",
	},
	{
		.key = "ro.aeesp",
		.value = "normal",
	},
	{
		.key = "ro.allow.mock.location",
		.value = "0",
	},
	{
		.key = "ro.audio.silent",
		.value = "0",
	},
	{
		.key = "ro.baseband",
		.value = "unknown",
	},
	{
		.key = "ro.board.platform",
		.value = "mt6797",
	},
	{
		.key = "ro.boot.bootreason",
		.value = "wdt_by_pass_pwk",
	},
	{
		.key = "ro.boot.hardware",
		.value = "mt6797",
	},
	{
		.key = "ro.boot.mode",
		.value = "normal",
	},
	{
		.key = "ro.boot.name",
		.value = "android",
	},
	{
		.key = "ro.boot.serialno",
		.value = "80MBCP5223WB",
	},
	{
		.key = "ro.boot.verifiedbootstate",
		.value = "green",
	},
	{
		.key = "ro.bootimage.build.date",
		.value = "Wed Jun 28 23:39:42 CST 2017",
	},
	{
		.key = "ro.bootimage.build.date.utc",
		.value = "1498664382",
	},
	{
		.key = "ro.bootimage.build.fingerprint",
		.value = "Meizu/full_meizu6797_6c_m/meizu6797_6c_m:6.0/MRA58K/1498663073:user/release-keys",
	},
	{
		.key = "ro.bootloader",
		.value = "unknown",
	},
	{
		.key = "ro.bootmode",
		.value = "normal",
	},
	{
		.key = "ro.build.characteristics",
		.value = "default",
	},
	{
		.key = "ro.build.cta",
		.value = "noncta",
	},
	{
		.key = "ro.build.date",
		.value = "Wed Jun 28 23:25:45 CST 2017",
	},
	{
		.key = "ro.build.date.utc",
		.value = "1498663545",
	},
	{
		.key = "ro.build.description",
		.value = "meizu_PRO6-user 6.0 MRA58K 1498663073 release-keys",
	},
	{
		.key = "ro.build.display.id",
		.value = "Flyme 6.1.0.0G",
	},
	{
		.key = "ro.build.fingerprint",
		.value = "Meizu/meizu_PRO6/PRO6:6.0/MRA58K/1498663073:user/release-keys",
	},
	{
		.key = "ro.build.flavor",
		.value = "full_meizu6797_6c_m-user",
	},
	{
		.key = "ro.build.host",
		.value = "mz-builder-l1",
	},
	{
		.key = "ro.build.id",
		.value = "MRA58K",
	},
	{
		.key = "ro.build.inside.id",
		.value = "6.0-20170628230554",
	},
	{
		.key = "ro.build.mask.id",
		.value = "6.0-1498662354_intlstable",
	},
	{
		.key = "ro.build.product",
		.value = "PRO6",
	},
	{
		.key = "ro.build.tags",
		.value = "release-keys",
	},
	{
		.key = "ro.build.type",
		.value = "user",
	},
	{
		.key = "ro.build.user",
		.value = "flyme",
	},
	{
		.key = "ro.build.version.all_codenames",
		.value = "REL",
	},
	{
		.key = "ro.build.version.base_os",
		.value = "",
	},
	{
		.key = "ro.build.version.codename",
		.value = "REL",
	},
	{
		.key = "ro.build.version.incremental",
		.value = "1498663073",
	},
	{
		.key = "ro.build.version.preview_sdk",
		.value = "0",
	},
	{
		.key = "ro.build.version.release",
		.value = "6.0",
	},
	{
		.key = "ro.build.version.sdk",
		.value = "23",
	},
	{
		.key = "ro.build.version.security_patch",
		.value = "2017-04-05",
	},
	{
		.key = "ro.camera.sound.forced",
		.value = "0",
	},
	{
		.key = "ro.carrier",
		.value = "unknown",
	},
	{
		.key = "ro.cip.build.date",
		.value = "Wed Jun 28 23:19:23 CST 2017",
	},
	{
		.key = "ro.com.android.dateformat",
		.value = "MM-dd-yyyy",
	},
	{
		.key = "ro.com.android.mobiledata",
		.value = "false",
	},
	{
		.key = "ro.config.alarm_alert",
		.value = "19_Waltz.ogg",
	},
	{
		.key = "ro.config.calendar_sound",
		.value = "03_Doorbell.ogg",
	},
	{
		.key = "ro.config.email_sound",
		.value = "02_Reminder.ogg",
	},
	{
		.key = "ro.config.mms_sound",
		.value = "01_Triumph.ogg",
	},
	{
		.key = "ro.config.notification_sound",
		.value = "02_Reminder.ogg",
	},
	{
		.key = "ro.config.ringtone",
		.value = "03_Flyme.ogg",
	},
	{
		.key = "ro.crypto.state",
		.value = "unencrypted",
	},
	{
		.key = "ro.dalvik.vm.native.bridge",
		.value = "0",
	},
	{
		.key = "ro.debuggable",
		.value = "0",
	},
	{
		.key = "ro.expect.recovery_id",
		.value = "0xc68184e76824cdec195acf3ae9c1a0b84b7f11d6000000000000000000000000",
	},
	{
		.key = "ro.flyme.published",
		.value = "true",
	},
	{
		.key = "ro.flyme.root.state",
		.value = "0",
	},
	{
		.key = "ro.flyme_softsim_tee_enable",
		.value = "1",
	},
	{
		.key = "ro.frp.pst",
		.value = "/dev/block/platform/mtk-msdc.0/11230000.msdc0/by-name/frp",
	},
	{
		.key = "ro.gemini.smart_sim_switch",
		.value = "false",
	},
	{
		.key = "ro.hardware",
		.value = "mt6797",
	},
	{
		.key = "ro.hardware.hifi.support",
		.value = "true",
	},
	{
		.key = "ro.have_aacencode_feature",
		.value = "1",
	},
	{
		.key = "ro.have_aee_feature",
		.value = "1",
	},
	{
		.key = "ro.hwui.disable_asset_atlas",
		.value = "true",
	},
	{
		.key = "ro.hwui.drop_shadow_cache_size",
		.value = "6",
	},
	{
		.key = "ro.hwui.fbo_cache_size",
		.value = "25",
	},
	{
		.key = "ro.hwui.gradient_cache_size",
		.value = "3",
	},
	{
		.key = "ro.hwui.layer_cache_size",
		.value = "32",
	},
	{
		.key = "ro.hwui.path_cache_size",
		.value = "32",
	},
	{
		.key = "ro.hwui.r_buffer_cache_size",
		.value = "8",
	},
	{
		.key = "ro.hwui.text_large_cache_height",
		.value = "1024",
	},
	{
		.key = "ro.hwui.text_large_cache_width",
		.value = "2048",
	},
	{
		.key = "ro.hwui.text_small_cache_height",
		.value = "1024",
	},
	{
		.key = "ro.hwui.text_small_cache_width",
		.value = "1024",
	},
	{
		.key = "ro.hwui.texture_cache_flushrate",
		.value = "0.4",
	},
	{
		.key = "ro.hwui.texture_cache_size",
		.value = "48",
	},
	{
		.key = "ro.kernel.zio",
		.value = "38,108,105,16",
	},
	{
		.key = "ro.mediatek.chip_ver",
		.value = "S01",
	},
	{
		.key = "ro.mediatek.gemini_support",
		.value = "true",
	},
	{
		.key = "ro.mediatek.platform",
		.value = "MT6797",
	},
	{
		.key = "ro.mediatek.project.path",
		.value = "device/meizu/meizu6797_6c_m",
	},
	{
		.key = "ro.mediatek.version.branch",
		.value = "alps-mp-m0.mp9",
	},
	{
		.key = "ro.mediatek.version.release",
		.value = "alps-mp-m0.mp9-V1.13.2_meizu6797.6c.m",
	},
	{
		.key = "ro.mediatek.version.sdk",
		.value = "4",
	},
	{
		.key = "ro.mediatek.wlan.p2p",
		.value = "1",
	},
	{
		.key = "ro.mediatek.wlan.wsc",
		.value = "1",
	},
	{
		.key = "ro.meizu.autorecorder",
		.value = "true",
	},
	{
		.key = "ro.meizu.build.spt",
		.value = "0",
	},
	{
		.key = "ro.meizu.carrier.model",
		.value = "M570H",
	},
	{
		.key = "ro.meizu.contactmsg.auth",
		.value = "false",
	},
	{
		.key = "ro.meizu.customize.pccw",
		.value = "false",
	},
	{
		.key = "ro.meizu.enable.stepcounter",
		.value = "true",
	},
	{
		.key = "ro.meizu.hardware.battery",
		.value = "DESAY_SONY",
	},
	{
		.key = "ro.meizu.hardware.emmc",
		.value = "BJNB4R",
	},
	{
		.key = "ro.meizu.hardware.psn",
		.value = "80QZZ132B074764",
	},
	{
		.key = "ro.meizu.hardware.version",
		.value = "0x57051001",
	},
	{
		.key = "ro.meizu.has_datamigration_app",
		.value = "true",
	},
	{
		.key = "ro.meizu.pcb.version",
		.value = "0x6",
	},
	{
		.key = "ro.meizu.permanentkey",
		.value = "false",
	},
	{
		.key = "ro.meizu.product.model",
		.value = "M5705",
	},
	{
		.key = "ro.meizu.project.id",
		.value = "m8097-5",
	},
	{
		.key = "ro.meizu.published.type",
		.value = "prd",
	},
	{
		.key = "ro.meizu.region.enable",
		.value = "true",
	},
	{
		.key = "ro.meizu.security",
		.value = "false",
	},
	{
		.key = "ro.meizu.setupwizard.flyme",
		.value = "true",
	},
	{
		.key = "ro.meizu.setupwizard.setlang",
		.value = "true",
	},
	{
		.key = "ro.meizu.sip.support",
		.value = "true",
	},
	{
		.key = "ro.meizu.tpid",
		.value = "1671168",
	},
	{
		.key = "ro.meizu.tptype",
		.value = "B",
	},
	{
		.key = "ro.meizu.visualvoicemail",
		.value = "true",
	},
	{
		.key = "ro.meizu.voip.support",
		.value = "false",
	},
	{
		.key = "ro.mount.fs",
		.value = "EXT4",
	},
	{
		.key = "ro.mtk_aal_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_afw_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_agps_app",
		.value = "1",
	},
	{
		.key = "ro.mtk_antibricking_level",
		.value = "2",
	},
	{
		.key = "ro.mtk_audenh_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_audio_ape_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_audio_tuning_tool_ver",
		.value = "V2.2",
	},
	{
		.key = "ro.mtk_benchmark_boost_tp",
		.value = "1",
	},
	{
		.key = "ro.mtk_bessurround_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_bg_power_saving_ui",
		.value = "1",
	},
	{
		.key = "ro.mtk_bip_scws",
		.value = "1",
	},
	{
		.key = "ro.mtk_blulight_def_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_bt_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_cam_lomo_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_cam_mfb_support",
		.value = "3",
	},
	{
		.key = "ro.mtk_cam_vfb",
		.value = "1",
	},
	{
		.key = "ro.mtk_cmcc_ft_precheck_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_cta_drm_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_cta_set",
		.value = "1",
	},
	{
		.key = "ro.mtk_deinterlace_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_dhcpv6c_wifi",
		.value = "1",
	},
	{
		.key = "ro.mtk_dialer_search_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_dual_mic_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_eap_sim_aka",
		.value = "1",
	},
	{
		.key = "ro.mtk_emmc_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_enable_md1",
		.value = "1",
	},
	{
		.key = "ro.mtk_epdg_support",
		.value = "0",
	},
	{
		.key = "ro.mtk_external_sim_only_slots",
		.value = "0",
	},
	{
		.key = "ro.mtk_external_sim_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_fd_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_flight_mode_power_off_md",
		.value = "0",
	},
	{
		.key = "ro.mtk_flv_playback_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_gemini_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_gps_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_hetcomm_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_ims_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_is_tablet",
		.value = "0",
	},
	{
		.key = "ro.mtk_lte_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_md_sbp_custom_value",
		.value = "0",
	},
	{
		.key = "ro.mtk_md_world_mode_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_miravision_image_dc",
		.value = "1",
	},
	{
		.key = "ro.mtk_miravision_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_mobile_management",
		.value = "1",
	},
	{
		.key = "ro.mtk_modem_monitor_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_oma_drm_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_omacp_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_passpoint_r1_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_perf_fast_start_win",
		.value = "0",
	},
	{
		.key = "ro.mtk_perf_response_time",
		.value = "1",
	},
	{
		.key = "ro.mtk_perf_simple_start_win",
		.value = "1",
	},
	{
		.key = "ro.mtk_perfservice_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_persist_vsim_disabled",
		.value = "1",
	},
	{
		.key = "ro.mtk_pq_color_mode",
		.value = "3",
	},
	{
		.key = "ro.mtk_pq_support",
		.value = "3",
	},
	{
		.key = "ro.mtk_privacy_protection_lock",
		.value = "1",
	},
	{
		.key = "ro.mtk_rild_read_imsi",
		.value = "1",
	},
	{
		.key = "ro.mtk_safemedia_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_search_db_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_send_rr_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_shared_sdcard",
		.value = "1",
	},
	{
		.key = "ro.mtk_sim_hot_swap",
		.value = "1",
	},
	{
		.key = "ro.mtk_sim_hot_swap_common_slot",
		.value = "1",
	},
	{
		.key = "ro.mtk_single_imei",
		.value = "1",
	},
	{
		.key = "ro.mtk_slidevideo_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_soter_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_tetheringipv6_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_thumbnail_play_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_trustonic_tee_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_vilte_support",
		.value = "0",
	},
	{
		.key = "ro.mtk_vilte_ut_support",
		.value = "0",
	},
	{
		.key = "ro.mtk_volte_support",
		.value = "0",
	},
	{
		.key = "ro.mtk_wapi_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_wappush_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_wfc_support",
		.value = "0",
	},
	{
		.key = "ro.mtk_wfd_sink_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_wfd_sink_uibc_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_wfd_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_widevine_drm_l3_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_wifi_mcc_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_wlan_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_wmv_playback_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_world_phone_policy",
		.value = "0",
	},
	{
		.key = "ro.mtk_zsdhdr_support",
		.value = "1",
	},
	{
		.key = "ro.opengles.version",
		.value = "196608",
	},
	{
		.key = "ro.product.board",
		.value = "PRO6",
	},
	{
		.key = "ro.product.brand",
		.value = "Meizu",
	},
	{
		.key = "ro.product.cpu.abi",
		.value = "arm64-v8a",
	},
	{
		.key = "ro.product.cpu.abilist",
		.value = "arm64-v8a,armeabi-v7a,armeabi",
	},
	{
		.key = "ro.product.cpu.abilist32",
		.value = "armeabi-v7a,armeabi",
	},
	{
		.key = "ro.product.cpu.abilist64",
		.value = "arm64-v8a",
	},
	{
		.key = "ro.product.device",
		.value = "PRO6",
	},
	{
		.key = "ro.product.flyme.model",
		.value = "8097",
	},
	{
		.key = "ro.product.locale",
		.value = "en-US",
	},
	{
		.key = "ro.product.manufacturer",
		.value = "Meizu",
	},
	{
		.key = "ro.product.mobile.name",
		.value = "m80",
	},
	{
		.key = "ro.product.model",
		.value = "PRO 6",
	},
	{
		.key = "ro.product.name",
		.value = "meizu_PRO6",
	},
	{
		.key = "ro.product.perf.config",
		.value = "M80_base",
	},
	{
		.key = "ro.recovery_id",
		.value = "0xc68184e76824cdec195acf3ae9c1a0b84b7f11d6000000000000000000000000",
	},
	{
		.key = "ro.revision",
		.value = "0",
	},
	{
		.key = "ro.runtime.firstboot",
		.value = "1503172932059",
	},
	{
		.key = "ro.secure",
		.value = "1",
	},
	{
		.key = "ro.serialno",
		.value = "80MBCP5223WB",
	},
	{
		.key = "ro.sf.hwrotation",
		.value = "0",
	},
	{
		.key = "ro.sf.lcd_density",
		.value = "480",
	},
	{
		.key = "ro.sim_me_lock_mode",
		.value = "0",
	},
	{
		.key = "ro.sim_refresh_reset_by_modem",
		.value = "1",
	},
	{
		.key = "ro.soc.vendor",
		.value = "MTK",
	},
	{
		.key = "ro.support.rpmb",
		.value = "0",
	},
	{
		.key = "ro.sys.usb.bicr",
		.value = "yes",
	},
	{
		.key = "ro.sys.usb.charging.only",
		.value = "yes",
	},
	{
		.key = "ro.sys.usb.mtp.whql.enable",
		.value = "0",
	},
	{
		.key = "ro.sys.usb.storage.type",
		.value = "mtp,mass_storage",
	},
	{
		.key = "ro.telephony.default_network",
		.value = "9",
	},
	{
		.key = "ro.telephony.sim.count",
		.value = "2",
	},
	{
		.key = "ro.wifi.channels",
		.value = "",
	},
	{
		.key = "ro.wlan.mtk.wifi.5g",
		.value = "1",
	},
	{
		.key = "ro.zygote",
		.value = "zygote64_32",
	},
	{
		.key = "ro.zygote.preload.enable",
		.value = "0",
	},
	{
		.key = "selinux.reload_policy",
		.value = "1",
	},
	{
		.key = "service.bootanim.exit",
		.value = "1",
	},
	{
		.key = "service.cat.install.on",
		.value = "0",
	},
	{
		.key = "service.cat.install.on.2",
		.value = "0",
	},
	{
		.key = "service.cat.install.on.3",
		.value = "0",
	},
	{
		.key = "service.cat.install.on.4",
		.value = "0",
	},
	{
		.key = "service.nvram_init",
		.value = "Ready",
	},
	{
		.key = "service.wcn.coredump.mode",
		.value = "0",
	},
	{
		.key = "service.wcn.driver.ready",
		.value = "yes",
	},
	{
		.key = "sys.boot.reason",
		.value = "0",
	},
	{
		.key = "sys.boot_completed",
		.value = "1",
	},
	{
		.key = "sys.ipo.pwrdncap",
		.value = "2",
	},
	{
		.key = "sys.ipowin.done",
		.value = "1",
	},
	{
		.key = "sys.lowstorage_flag",
		.value = "0",
	},
	{
		.key = "sys.meizu.m35x.white.config",
		.value = "false",
	},
	{
		.key = "sys.meizu.white.config",
		.value = "false",
	},
	{
		.key = "sys.oem_unlock_allowed",
		.value = "0",
	},
	{
		.key = "sys.settings_global_version",
		.value = "2",
	},
	{
		.key = "sys.sysctl.extra_free_kbytes",
		.value = "32400",
	},
	{
		.key = "sys.usb.charging",
		.value = "no",
	},
	{
		.key = "sys.usb.config",
		.value = "mtp,adb",
	},
	{
		.key = "sys.usb.ffs.ready",
		.value = "1",
	},
	{
		.key = "sys.usb.state",
		.value = "mtp,adb",
	},
	{
		.key = "sys.usb.vid",
		.value = "2A45",
	},
	{
		.key = "telecom.cts.exist",
		.value = "false",
	},
	{
		.key = "vold.has_adoptable",
		.value = "0",
	},
	{
		.key = "vold.path.internal_storage",
		.value = "/storage/emulated/0",
	},
	{
		.key = "vold.post_fs_data_done",
		.value = "1",
	},
	{
		.key = "vold.support_external_sd",
		.value = "1",
	},
	{
		.key = "wfd.dummy.enable",
		.value = "1",
	},
	{
		.key = "wfd.iframesize.level",
		.value = "0",
	},
	{
		.key = "wifi.direct.interface",
		.value = "p2p0",
	},
	{
		.key = "wifi.interface",
		.value = "wlan0",
	},
	{
		.key = "wifi.tethering.interface",
		.value = "ap0",
	},
	{
		.key = "wlan.driver.status",
		.value = "ok",
	},
	{
		.key = "wlan.wfd.security.image",
		.value = "1",
	},
	{ NULL },
};
#endif /* __ANDROID__ */
